@@ -7,8 +7,7 @@ use strict;
 use warnings;
 #use Carp;
 
-our $VERSION = '0.01_02';
-our $ISA     = qw/Qt::Core::QObject/;
+our $VERSION = '0.01_03';
 
 
 # FIXME: operator overload
@@ -28,9 +27,9 @@ Qt::Multimedia::QAbstractAudioDeviceInfo
 
 =item  QString deviceName()
 
-=item  bool isFormatSupported()
+=item  bool isFormatSupported(const QAudioFormat & format)
 
-=item  QAudioFormat nearestFormat()
+=item  QAudioFormat nearestFormat(const QAudioFormat & format)
 
 =item  QAudioFormat preferredFormat()
 
